@@ -4,4 +4,4 @@ from .csvreader import CsvReader
 from .fakereader import FakeReader
 from .bedreader import BedReader
 from .pedreader import PedReader
-from .abstractreader import check_field_schema, check_variant_schema
+from .abstractreader import AbstractReader, check_field_schema, check_variant_schema
