@@ -14,6 +14,7 @@ from logging import DEBUG
 from PySide6.QtCore import (
     QEventLoop,
     QStandardPaths,
+    QThread,
     Qt,
     QSettings,
     QByteArray,
@@ -190,6 +191,7 @@ class MainWindow(QMainWindow):
         )
 
         search_bar = self.addToolBar("Search")
+        search_bar.setObjectName("search")
         search_bar.addWidget(self.quick_search_edit)
 
         # Window geometry
@@ -323,7 +325,7 @@ class MainWindow(QMainWindow):
             long_description = extension.get("long_description", "")
             short_description = extension.get("description", "")
             widget.setWhatsThis(long_description)
-            widget.setToolTip(short_description)
+            # widget.setToolTip(short_description)
             # Register (launch first init on some of them)
             widget.mainwindow = self
             widget.on_register(self)
@@ -417,20 +419,23 @@ class MainWindow(QMainWindow):
         ## File Menu
         self.file_menu = self.menuBar().addMenu(self.tr("&File"))
         self.new_project_action = self.file_menu.addAction(
-            FIcon(0xF0415), self.tr("&New project"), self.new_project, QKeySequence.New
+            FIcon(0xF0415), self.tr("&New Project"), self.new_project, QKeySequence.New
         )
+        self.new_project_action.setToolTip(self.tr("Create a new database and import data"))
         self.open_project_action = self.file_menu.addAction(
             FIcon(0xF0DCF),
-            self.tr("&Open project..."),
+            self.tr("&Open a Project"),
             self.open_project,
             QKeySequence.Open,
         )
+        self.open_project_action.setToolTip(self.tr("Open a database"))
         self.import_file_action = self.file_menu.addAction(
-            FIcon(0xF102F),
-            self.tr("&Import file"),
+            FIcon(0xF02FA),
+            self.tr("&Import a file"),
             self.import_file,
             QKeySequence.AddTab,
         )
+        self.import_file_action.setToolTip(self.tr("Import a file into the current database"))
 
         self.toolbar.addAction(self.new_project_action)
         self.toolbar.addAction(self.open_project_action)
@@ -470,10 +475,17 @@ class MainWindow(QMainWindow):
 
         self.file_menu.addSeparator()
 
-        self.file_menu.addAction(FIcon(0xF0193), self.tr("Save session ..."), self.on_save_session)
-        self.file_menu.addAction(
-            FIcon(0xF0770), self.tr("Restore session ..."), self.on_load_session
+        save_session_action = self.file_menu.addAction(
+            FIcon(0xF0818), self.tr("Save session ..."), self.on_save_session
         )
+        save_session_action.setToolTip(self.tr("Save current session into a file"))
+        load_session_action = self.file_menu.addAction(
+            FIcon(0xF0DCF), self.tr("Restore session ..."), self.on_load_session
+        )
+        load_session_action.setToolTip(self.tr("Load a session from a file "))
+
+        self.toolbar.addAction(save_session_action)
+        self.toolbar.addAction(load_session_action)
 
         self.file_menu.addSeparator()
         ### Misc
@@ -506,11 +518,6 @@ class MainWindow(QMainWindow):
         self.view_menu = self.menuBar().addMenu(self.tr("&View"))
         self.view_menu.addAction(self.tr("Reset widgets positions"), self.reset_ui)
         # Set toggle footer visibility action
-        show_action = self.view_menu.addAction(FIcon(0xF018D), self.tr("Show VQL editor"))
-        show_action.setCheckable(True)
-        self.toolbar.addAction(show_action)
-        show_action.setChecked(True)
-        show_action.toggled.connect(self.toggle_footer_visibility)
 
         fullscreen_action = self.view_menu.addAction(
             self.tr("Enter Full Screen"),
@@ -560,7 +567,7 @@ class MainWindow(QMainWindow):
             self.about_cutevariant,
         )
 
-    def open_database_from_file(self, filepath):
+    def open_database_from_file(self, filepath, reset=True):
         """Open the given db/project file
 
         .. note:: Called at the end of a project creation by the Wizard,
@@ -591,7 +598,7 @@ class MainWindow(QMainWindow):
                 )
                 return
 
-            self.open_database(self.conn)
+            self.open_database(self.conn, reset)
             self.save_recent_project(filepath)
 
         except sqlite3.OperationalError as e:
@@ -607,7 +614,7 @@ class MainWindow(QMainWindow):
         self.setWindowTitle("Cutevariant - %s" % os.path.basename(filepath))
         self.status_bar.showMessage(self.tr("{} opened").format(filepath))
 
-    def open_database(self, conn):
+    def open_database(self, conn, reset=True):
         """Open the project file and populate widgets
 
         Args:
@@ -616,7 +623,8 @@ class MainWindow(QMainWindow):
 
         self.conn = conn
 
-        # self._state_data.reset()
+        if reset:
+            self._state_data.reset()
 
         # Clear memoization cache for count_cmd
         sql.clear_lru_cache()
@@ -975,6 +983,9 @@ class MainWindow(QMainWindow):
     def save_session(self, filename: str):
         """save plugin state into a json file"""
 
+        if not self.conn:
+            return
+
         session = {
             "db_path": sql.get_database_file_name(self.conn),
             "fields": self.get_state_data("fields"),
@@ -989,6 +1000,10 @@ class MainWindow(QMainWindow):
         for name, plugin in self.plugins.items():
             session["plugins"][name] = plugin.to_json()
 
+        config_dir = os.path.dirname(filename)
+        if not os.path.exists(config_dir):
+            os.makedirs(config_dir)
+
         with open(filename, "w") as file:
             json.dump(session, file)
 
@@ -1010,19 +1025,18 @@ class MainWindow(QMainWindow):
             state = json.load(file)
 
         if "db_path" in state:
-
             self.set_state_data("fields", state.get("fields", []))
             self.set_state_data("source", state.get("source", "variants"))
             self.set_state_data("filters", state.get("filters", {}))
             self.set_state_data("order_by", state.get("order_by", []))
             self.set_state_data("samples", state.get("samples", []))
 
-            if "plugins" in state:
-                for name, plugin in self.plugins.items():
-                    if name in state["plugins"]:
-                        plugin.from_json(state["plugins"][name])
+            self.open_database_from_file(state["db_path"], reset=False)
 
-            self.open_database_from_file(state["db_path"])
+            # if "plugins" in state:
+            #     for name, plugin in self.plugins.items():
+            #         if name in state["plugins"]:
+            #             plugin.from_json(state["plugins"][name])
 
     def write_settings(self):
         """Store the state of this mainwindow.
@@ -1055,13 +1069,17 @@ class MainWindow(QMainWindow):
             #  TODO: handle UI changes by passing UI_VERSION to saveState()
             self.app_settings.setValue("windowState", self.saveState())
 
-    def toggle_footer_visibility(self, visibility):
+    def toggle_footer_visibility(self, visibility=None):
         """Toggle visibility of the bottom toolbar and all its plugins"""
-        # self.footer_tab.setVisible(visibility)
-        if not visibility:
-            self.vsplit.setSizes([100, 0])
-        else:
-            self.vsplit.setSizes([200, 100])
+
+        if visibility is None:
+            visibility = not self.footer_tab.isVisible()
+
+        self.footer_tab.setVisible(visibility)
+        # if not visibility:
+        #     self.vsplit.setSizes([100, 0])
+        # else:
+        #     self.vsplit.setSizes([200, 100])
 
     def on_export_pressed(self):
         """
@@ -1123,6 +1141,7 @@ class MainWindow(QMainWindow):
             fields=self.get_state_data("fields"),
             source=self.get_state_data("source"),
             filters=self.get_state_data("filters"),
+            samples=self.get_state_data("samples"),
         )
 
         # # TODO : refactor self.state
