@@ -82,13 +82,12 @@ import importlib
 import pkgutil
 
 # Qt imports
-from PySide2.QtWidgets import QWidget, QDialog
+from PySide6.QtWidgets import QWidget, QDialog
 
 # Cutevariant import
 from cutevariant.config import Config
 from cutevariant.gui import settings
 import cutevariant.commons as cm
-
 from cutevariant import LOGGER
 
 DOCK_LOCATION = 1
@@ -161,6 +160,11 @@ class PluginWidget(QWidget):
         """
         pass
 
+    def on_close_project(self):
+        """This method is callen when a project is closed"""
+
+        pass
+
     def on_close(self):
         """Called when the mainwindow is closed **or** when the plugin is reset.
 
@@ -189,11 +193,11 @@ class PluginWidget(QWidget):
         pass
 
     def to_json(self):
-        """ serialize plugin state into dict"""
+        """serialize plugin state into dict"""
         return {}
 
     def from_json(self, json: dict):
-        """ read plugin state from json dict """
+        """read plugin state from json dict"""
         pass
 
     def showEvent(self, event):
@@ -206,7 +210,7 @@ class PluginWidget(QWidget):
             avoid surprises due to an early call of `on_refresh`.
 
         Args:
-            event(PySide2.QtGui.QShowEvent):
+            event(PySide6.QtGui.QShowEvent):
         """
 
         if self.conn and not self._STARTUP:
@@ -364,9 +368,7 @@ def find_plugins(path=None):
             sub_module_path = os.path.join(
                 sub_module_info.module_finder.path, sub_module_type + ".py"
             )
-            spec = importlib.util.spec_from_file_location(
-                sub_module_type, sub_module_path
-            )
+            spec = importlib.util.spec_from_file_location(sub_module_type, sub_module_path)
             sub_module = spec.loader.load_module()
 
             # Filter not wanted classes (search main classes of the module)
