@@ -1,4 +1,4 @@
-__title__ = "Trio analysis plugin"
+__title__ = "Trio analysis"
 __description__ = "A dialog to create filters for a specific trio analysis"
 __long_description__ = ""
 __author__ = "Sacha schutz"
